/**************************************************************************
 *  MuseScore - Music notation program                                    *
 *  PlugIn for Linux - Alto Recorder Tablature (baroque fingering system) *
 *  $Id:$                                                                 *
 *                                                                        *
 *  Copyright (C) 2012 Kai Christian Heitkamp                             *
 *  dynup@ymail.com | http://dynup.de.vu                                  *
 *                                                                        *
 *  Copyright (C) 2011 Dario Escobedo, Werner Schweer and others.         *
 *  werner@musescore.org | http://musescore.org                           *
 *                                                                        *
 *  This is a variation of Werner Schweer very famous recorder_fingering  *
 *  plugin using Matthew Hindson Woodwind Tablature font. All free fonts  *
 *  from Matthew Hindson are located here:                                *
 *  www.hindson.com.au/wordpress/free/free-fonts-available-for-download   *
 *                                                                        *
 *  This program is free software; you can redistribute it and/or modify  *
 *  it under the terms of the GNU General Public License as published by  *
 *  the Free Software Foundation; either version 3 of the License, or     *
 *  (at your option) any later version.                                   *
 *                                                                        *
 *  This program is distributed in the hope that it will be useful,       *
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *  GNU General Public License for more details.                          *
 *                                                                        *
 *  You should have received a copy of the GNU General Public License     *
 *  along with this program; if not, go to http://www.gnu.org             *
 **************************************************************************/

//
// This is ECMAScript code (ECMA-262 aka "Java Script")
// Plugin for MuseScore
//

var fingerings = [ " ", " ", " ", " ", " ", "a", "A", "s", "D", "d",
                   "f", "F", "g", "V", "h", "H", "j", "q", "Q", "w",
                   "W", "e", "r", "R", "t", "T", "y", "U", "u", "i",
                   "N", "m", " ", " ", " ", " ", " " ]

//---------------------------------------------------------
//    init
//    this function will be called on startup of mscore
//---------------------------------------------------------

function init() {
}

//-------------------------------------------------------------------
//    run
//    this function will be called when activating the
//    plugin menu entry
//-------------------------------------------------------------------

function run() {
  var font = new QFont("woodwind tablature", 15);
  var cursor = new Cursor(curScore);

  cursor.staff = 0;
  cursor.voice = 0;
  cursor.rewind();

  while (!cursor.eos()) {
    if (cursor.isChord()) {
      var pitch = cursor.chord().topNote().pitch;
      var index = pitch - 60;

      if (index >= 0 && index < fingerings.length) { 
        var text  = new Text(curScore);
        text.text = fingerings[index];
        text.defaultFont = font;
        text.yOffset = 6;

        cursor.putStaffText(text);
      }
    }
    
    cursor.next();
  }
}

//---------------------------------------------------------
//    menu:  defines were the function will be placed
//           in the MuseScore menu structure
//---------------------------------------------------------

var mscorePlugin = {
  majorVersion:  1,
  minorVersion:  0,
  menu: 'Plugins.Alto Recorder Tablature',
  init: init,
  run:  run
};

mscorePlugin;

